Index: src/heap/heap.h |
diff --git a/src/heap/heap.h b/src/heap/heap.h |
index 4f624a3ab4b538d0b0eb128fc094516d6e03883c..4a5052310efaddd209c8c9bc0ce65cbf9defda74 100644 |
--- a/src/heap/heap.h |
+++ b/src/heap/heap.h |
@@ -729,9 +729,11 @@ class Heap { |
bool CanMoveObjectStart(HeapObject* object); |
- // Indicates whether live bytes adjustment is triggered from within the GC |
- // code or from mutator code. |
- enum InvocationMode { FROM_GC, FROM_MUTATOR }; |
+ // Indicates whether live bytes adjustment is triggered |
+ // - from within the GC code before sweeping started (SEQUENTIAL_TO_SWEEPER), |
+ // - or from within GC (CONCURRENT_TO_SWEEPER), |
+ // - or mutator code (CONCURRENT_TO_SWEEPER). |
+ enum InvocationMode { SEQUENTIAL_TO_SWEEPER, CONCURRENT_TO_SWEEPER }; |
// Maintain consistency of live bytes during incremental marking. |
void AdjustLiveBytes(Address address, int by, InvocationMode mode); |